@@ -4,10 +4,10 @@ import IPython
 
 DatosList = []
 
+#from artemix.latemix import *
+
 #https://widdowquinn.github.io/coding/update-pypi-package/
 
-
-
 def Inicializar(n):
   global DatosList,Orden,Estilo
 
@@ -164,4 +164,3 @@ def R(string):
   display(IPython.display.Latex(string))  
 
 
-from artemix.latemix import *
\ No newline at end of file
